<?php
/**
 * The header for our theme
 *
 * @subpackage Home Construction
 * @since 1.0
 * @version 0.1
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js no-svg">
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open();
} else {
    do_action( 'wp_body_open' );
}?>

<a class="screen-reader-text skip-link" href="#skip-content"><?php esc_html_e( 'Skip to content', 'home-construction' ); ?></a>

<div id="header">
	<div class="container">
		<div class="header-content">
			<div class="menu-section">
				<div class="toggle-menu responsive-menu">
					<?php if(has_nav_menu('primary')){ ?>
		            	<button onclick="home_construction_open()" role="tab" class="mobile-menu"><i class="fas fa-bars"></i><span class="screen-reader-text"><?php esc_html_e('Open Menu','home-construction'); ?></span></button>
		            <?php }?>
		        </div>
				<div id="sidelong-menu" class="nav sidenav">
	                <nav id="primary-site-navigation" class="nav-menu" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'home-construction' ); ?>">
	                  	<?php if(has_nav_menu('primary')){
		                    wp_nav_menu( array( 
								'theme_location' => 'primary',
								'container_class' => 'main-menu-navigation clearfix' ,
								'menu_class' => 'clearfix',
								'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
								'fallback_cb' => 'wp_page_menu',
		                    ) ); 
	                  	} ?>
	                  	<a href="javascript:void(0)" class="closebtn responsive-menu" onclick="home_construction_close()"><i class="fas fa-times"></i><span class="screen-reader-text"><?php esc_html_e('Close Menu','home-construction'); ?></span></a>
	                </nav>
	            </div>
			</div>
			<div class="bottom-header">
				<div class="row">
					<div class="col-lg-5 col-md-6 align-self-center">
						<div class="logo">
							<?php if ( has_custom_logo() ) : ?>
			            		<?php the_custom_logo(); ?>
				            <?php endif; ?>
			             	<?php if (get_theme_mod('home_construction_show_site_title',true)) {?>
			          			<?php $blog_info = get_bloginfo( 'name' ); ?>
				                <?php if ( ! empty( $blog_info ) ) : ?>
				                  	<?php if ( is_front_page() && is_home() ) : ?>
				                    	<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
				                  	<?php else : ?>
			                      		<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
			                  		<?php endif; ?>
				                <?php endif; ?>
				            <?php }?>
				            <?php if (get_theme_mod('home_construction_show_tagline',true)) {?>
				                <?php
			                  		$description = get_bloginfo( 'description', 'display' );
				                  	if ( $description || is_customize_preview() ) :
				                ?>
			                  	<p class="site-description">
			                    	<?php echo esc_attr($description); ?>
			                  	</p>
			              		<?php endif; ?>
			          		<?php }?>
						</div>
					</div>
					<div class="col-lg-7 col-md-6">
						<div class="social-icons py-2 text-md-right text-center">
							<?php if(get_theme_mod('home_construction_topheader_facebook_url')) {?>
								<a href="<?php echo esc_url(get_theme_mod('home_construction_topheader_facebook_url')); ?>"><i class="fab fa-facebook-f"></i><span class="screen-reader-text"><?php echo esc_html('Facebook', 'home-construction'); ?></span></a>
							<?php }?>
							<?php if(get_theme_mod('home_construction_topheader_twitter_url')) {?>
								<a href="<?php echo esc_url(get_theme_mod('home_construction_topheader_twitter_url')); ?>"><i class="fab fa-twitter"></i><span class="screen-reader-text"><?php echo esc_html('Twitter', 'home-construction'); ?></span></a>
							<?php }?>
							<?php if(get_theme_mod('home_construction_topheader_instagram_url')) {?>
								<a href="<?php echo esc_url(get_theme_mod('home_construction_topheader_instagram_url')); ?>"><i class="fab fa-instagram"></i><span class="screen-reader-text"><?php echo esc_html('Instagram', 'home-construction'); ?></span></a>
							<?php }?>
							<?php if(get_theme_mod('home_construction_topheader_linkedin_url')) {?>
								<a href="<?php echo esc_url(get_theme_mod('home_construction_topheader_linkedin_url')); ?>"><i class="fab fa-linkedin-in"></i><span class="screen-reader-text"><?php echo esc_html('Linkedin', 'home-construction'); ?></span></a>
							<?php }?>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>